/**
 * Layouts module index
 */

export { FlexibleLayout } from './FlexibleLayout'
export {
    WIDGET_REGISTRY,
    renderWidget,
    StatsCard,
    QuickLinks,
    Newsletter,
    SocialLinks,
    Copyright,
    HeroBanner
} from './widgets'

// Chat layouts
export { ChatLayout } from './ChatLayout'
export { AgentUILayout } from './AgentUILayout'
export { CopilotWidget } from './CopilotWidget'
export { PlaygroundLayout } from './PlaygroundLayout'
export { DashboardLayout } from './DashboardLayout'
